@@ -32,6 +32,14 @@ fm1 <- lme(distance ~ age, data = Orthodont,
 	   control = lmeControl(msMaxIter = 1, returnObject = TRUE))
 )
 
+## "typo" in 'random=' -- giving 27-dim. vector random effect:
+## PR#17524 B.Tyner: https://bugs.r-project.org/bugzilla/show_bug.cgi?id=17524
+               try(lme(distance ~ 1,   data=Orthodont, random = ~ Subject))
+tools::assertError(lme(distance ~ age, data=Orthodont, random = ~ Subject))
+## seg.faults in nlme <= 3.1-137 (2018) because of integer overflow
+## The previous warning is now an *error* (unless new lmeControl(allow.n.lt.q=TRUE))
+
+
 ## based on bug report on R-help
 (p3.1 <- predict(fm3, Orthodont[1,]))
 # failed in 3.1-88
@@ -40,7 +48,7 @@ stopifnot(all.equal(pm3[1], p3.1,
 
 ## Intervals failed in a patch proposal (Nov.2015):
 (fm4 <- lme(distance ~ age, Orthodont, random = ~ age | Subject))
-(i4 <- intervals(fm4))
+i4 <- intervals(fm4)
 ## from  dput(signif(i4$reStruct$Subject, 8))
 ## R-devel 2016-01-11; 64-bit :
 reSS <- data.frame(lower = c(0.9485605, 0.10250901, -0.93825047),
@@ -66,11 +74,16 @@ stopifnot(
     all.equal(as.vector(i4$sigma),
               ##  lower     est.        upper
               c(1.0849772, 1.3100397, 1.5817881), tol=8e-4)
+   ,
+    all.equal(as.vector(i4$fixed),
+              as.vector(rbind(c(15.218322, 16.761111, 18.3039),
+                              c(0.51838667, 0.66018519, 0.8019837))),
+              tol = 1e-6)
 )
 
 
 ## wrong results from getData:
-load("ss2.rda")
+ss2 <- readRDS("ss2.rds")
 m1 <- lme(PV1MATH ~  ESCS + Age +time ,
           random = ~   time|SCHOOLID,
           data = ss2,
@@ -86,3 +99,17 @@ m2 <- lme(PV1MATH ~  ESCS + Age +time ,
           corr = corCompSymm(form=~1|SCHOOLID/StIDStd),
           na.action = na.omit)
 plot(m2, resid(.) ~ WEALTH)
+
+
+## Variogram() failing in the case of  1-observation groups (PR#17192):
+BW <- subset(BodyWeight, ! (Rat=="1" & Time > 1))
+if(interactive())
+    print( xtabs(~ Rat + Time, data = BW) )# Rat '1' only at Time == 1
+fm2 <- lme(fixed = weight ~ Time * Diet, random = ~ 1 | Rat, data = BW)
+Vfm2 <- Variogram(fm2, form = ~ Time | Rat)
+stopifnot(is.data.frame(Vfm2),
+	  identical(dim(Vfm2), c(19L, 3L)),
+	  all.equal(unlist(Vfm2[10,]), c(variog = 1.08575384191148,
+					 dist = 22, n.pairs = 15))
+	  )
+## failed in nlme from 3.1-122 till 3.1-128
